# github:python-whois
# pypi: whois

  * A Python package for retrieving WHOIS information of DOMAIN'S ONLY.

**NOTICE: AS OF 2024-02-03; THIS SOFTWARE IS NOW UNSUPPORTED**

ALL FURTHER ACTIONS WILL TAKE PLACE AT
[WhoisDomain](https://github.com/mboot-github/WhoisDomain)

For all further info:

  * see [WhoisDomain](https://github.com/mboot-github/WhoisDomain)
  * all future development will take place on WhoisDomain

